# OpenBB Finviz Data Provider Extension

This extension integrates the [Finviz](https://finviz.com/) data provider into the OpenBB Platform.

## Installation

To install the extension:

```bash
pip install openbb-finviz
```

Documentation available [here](https://docs.openbb.co/platform/developer_guide/contributing).
